@@ -1,8 +1,3 @@
-/* $Id: extern.h,v 1.3 2001/11/12 18:14:14 hpa Exp $ */
-
-/* $OpenBSD: extern.h,v 1.2 1996/06/26 05:40:33 deraadt Exp $	*/
-/* $NetBSD: extern.h,v 1.2 1994/12/08 09:51:24 jtc Exp $	*/
-
 /*
  * Copyright (c) 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -34,14 +29,15 @@
  * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
- *
- *	@(#)extern.h	8.1 (Berkeley) 6/6/93
  */
 
-#ifndef RECVFILE_H
-#define RECVFILE_H
+#ifndef EXTERN_H
+#define EXTERN_H
 
-void	tftp_recvfile (int, char *, char *);
-void	tftp_sendfile (int, char *, char *);
+#include "config.h"
+
+void tftp_recvfile(int, const char *, const char *);
+void tftp_sendfile(int, const char *, const char *);
+extern sigjmp_buf toplevel;
 
 #endif
