@@ -1,6 +1,6 @@
 /* ----------------------------------------------------------------------- *
  *
- *   Copyright 2001 H. Peter Anvin - All Rights Reserved
+ *   Copyright 2001-2025 H. Peter Anvin - All Rights Reserved
  *
  *   This program is free software available under the same license
  *   as the "OpenBSD" operating system, distributed at
@@ -17,9 +17,17 @@
 #ifndef TFTPD_TFTPD_H
 #define TFTPD_TFTPD_H
 
+#include "config.h"
+#include <syslog.h>
+
+typedef void (*log_func)(int, const char *, ...);
+extern log_func tftpd_log;
+
 void set_signal(int, void (*)(int), int);
 void *tfmalloc(size_t);
 char *tfstrdup(const char *);
+void *tfrealloc(void *, size_t);
+void tffree(void *);
 
 extern int verbosity;
 
